Installation
============

This tutorial will walk you through the process of building pymetis. To follow,
you really only need three basic things:

* A UNIX-like machine with web access.
* A C++ compiler, preferably a Version 4.x gcc.
* A working `Python <http://www.python.org>`_ installation.

With those prerequisites, the following command should suffice::

    pip install pymetis

License
=======

.. include:: ../LICENSE
